==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/GCPDNSZoneSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class GCPDNSZoneSpecBuilder extends GCPDNSZoneSpecFluentImpl<GCPDNSZoneSpecBuilder> implements VisitableBuilder<GCPDNSZoneSpec,GCPDNSZoneSpecBuilder>{
  public GCPDNSZoneSpecBuilder() {
    this(false);
  }
  public GCPDNSZoneSpecBuilder(Boolean validationEnabled) {
    this(new GCPDNSZoneSpec(), validationEnabled);
  }
  public GCPDNSZoneSpecBuilder(GCPDNSZoneSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public GCPDNSZoneSpecBuilder(GCPDNSZoneSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new GCPDNSZoneSpec(), validationEnabled);
  }
  public GCPDNSZoneSpecBuilder(GCPDNSZoneSpecFluent<?> fluent,GCPDNSZoneSpec instance) {
    this(fluent, instance, false);
  }
  public GCPDNSZoneSpecBuilder(GCPDNSZoneSpecFluent<?> fluent,GCPDNSZoneSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public GCPDNSZoneSpecBuilder(GCPDNSZoneSpec instance) {
    this(instance,false);
  }
  public GCPDNSZoneSpecBuilder(GCPDNSZoneSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  GCPDNSZoneSpecFluent<?> fluent;
  Boolean validationEnabled;
  public GCPDNSZoneSpec build() {
    GCPDNSZoneSpec buildable = new GCPDNSZoneSpec(fluent.getCredentialsSecretRef());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/GCPDNSZoneSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class GCPDNSZoneSpecBuilder extends GCPDNSZoneSpecFluent<GCPDNSZoneSpecBuilder> implements VisitableBuilder<GCPDNSZoneSpec,GCPDNSZoneSpecBuilder>{
  public GCPDNSZoneSpecBuilder() {
    this(false);
  }
  public GCPDNSZoneSpecBuilder(Boolean validationEnabled) {
    this(new GCPDNSZoneSpec(), validationEnabled);
  }
  public GCPDNSZoneSpecBuilder(GCPDNSZoneSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public GCPDNSZoneSpecBuilder(GCPDNSZoneSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new GCPDNSZoneSpec(), validationEnabled);
  }
  public GCPDNSZoneSpecBuilder(GCPDNSZoneSpecFluent<?> fluent,GCPDNSZoneSpec instance) {
    this(fluent, instance, false);
  }
  public GCPDNSZoneSpecBuilder(GCPDNSZoneSpecFluent<?> fluent,GCPDNSZoneSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new GCPDNSZoneSpec());

    if (instance != null) {
      fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public GCPDNSZoneSpecBuilder(GCPDNSZoneSpec instance) {
    this(instance,false);
  }
  public GCPDNSZoneSpecBuilder(GCPDNSZoneSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new GCPDNSZoneSpec());

    if (instance != null) {
      this.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      this.withCredentialsSecretRef(instance.getCredentialsSecretRef());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  GCPDNSZoneSpecFluent<?> fluent;
  Boolean validationEnabled;
  public GCPDNSZoneSpec build() {
    GCPDNSZoneSpec buildable = new GCPDNSZoneSpec(fluent.buildCredentialsSecretRef());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
